@@ -7,7 +7,6 @@ use Carp qw(confess);
 use File::Find;
 use File::Spec;
 use Set::Tiny;
-use File::Path qw(make_path);
 
 use Jenkins::i18n::Properties;
 
@@ -19,7 +18,7 @@ Jenkins::i18n - functions for the jtt CLI
 
 =head1 SYNOPSIS
 
-  use Jenkins::i18n qw(remove_unused);
+  use Jenkins::i18n qw(remove_unused find_files load_properties load_jelly find_langs);
 
 =head1 DESCRIPTION
 
@@ -31,11 +30,11 @@ This module implements some of the functions used by the CLI.
 
 use Exporter 'import';
 our @EXPORT_OK = (
-    'remove_unused', 'find_files', 'print_license', 'load_properties',
-    'load_jelly',    'find_langs'
+    'remove_unused', 'find_files', 'load_properties', 'load_jelly',
+    'find_langs'
 );
 
-our $VERSION = '0.06';
+our $VERSION = '0.08';
 
 =head2 EXPORT
 
@@ -124,9 +123,9 @@ sub remove_unused {
 
 =head2 find_files
 
-Find all files Jelly and Java Properties files that could be translated from
-English, i.e., files that do not have a ISO 639-1 standard language based code
-as a filename prefix (before the file extension).
+Find all Jelly and Java Properties files that could be translated from English,
+i.e., files that do not have a ISO 639-1 standard language based code as a
+filename prefix (before the file extension).
 
 Expects as parameter a complete path to a directory that might contain such
 files.
@@ -173,7 +172,7 @@ my $regex = qr/_([a-z]{2})(_[A-Z]{2})?\.properties$/;
 =head2 find_langs
 
 Finds all ISO 639-1 standard language based codes available in the Jenkins
-repository based on the filenames prefix (before the file extension) of the
+repository based on the filenames sufix (before the file extension) of the
 translated files.
 
 This is basically the opposite of C<find_files> does.
@@ -184,12 +183,6 @@ files.
 Returns a instance of the L<Set::Tiny> class containing all the language codes
 that were identified.
 
-=back
-
-Find all files Jelly and Java Properties files that could be translated from
-English, i.e., files that do not have a ISO 639-1 standard language based code
-as a filename prefix (before the file extension).
-
 =cut
 
 sub find_langs {
@@ -226,46 +219,6 @@ sub find_langs {
     return $langs;
 }
 
-=head2 print_license
-
-Print a license text to new files.
-
-Expects as parameters:
-
-=over
-
-=item 1
-
-the complete path to the file
-
-=item 2
-
-an array reference with the license text.
-
-=back
-
-=cut
-
-sub print_license {
-    my ( $file, $data_ref ) = @_;
-    confess 'The complete path to the file parameter is required'
-        unless ($file);
-    confess 'The data reference parameter is required' unless ($data_ref);
-    confess 'The data reference must be an array reference'
-        unless ( ref($data_ref) eq 'ARRAY' );
-
-    # only dirs part is desired
-    my $dirs = ( File::Spec->splitpath($file) )[1];
-    make_path($dirs) unless ( -d $dirs );
-    open( my $out, '>', $file ) or confess "Cannot write to $file: $!\n";
-
-    foreach my $line ( @{$data_ref} ) {
-        print $out "#$line";
-    }
-
-    close($out);
-}
-
 =head2 load_properties
 
 Loads the content of a Java Properties file into a hash.
@@ -389,9 +342,9 @@ details.
 You should have received a copy of the GNU General Public License along with
 Jenkins Translation Tool. If not, see (http://www.gnu.org/licenses/).
 
-The original `translation-tool.pl` script was licensed through the MIT License,
-copyright (c) 2004-, Kohsuke Kawaguchi, Sun Microsystems, Inc., and a number of
-other of contributors. Translations files generated by the Jenkins Translation
-Tool CLI are distributed with the same MIT License.
+The original C<translation-tool.pl> script was licensed through the MIT
+License, copyright (c) 2004-, Kohsuke Kawaguchi, Sun Microsystems, Inc., and a
+number of other of contributors. Translations files generated by the Jenkins
+Translation Tool CLI are distributed with the same MIT License.
 
 =cut
