@@ -7,17 +7,17 @@ use Hash::Util qw(lock_keys);
 use Carp qw(confess);
 use Cwd;
 
-our $VERSION = '0.06';
+our $VERSION = '0.08';
 
 =pod
 
 =head1 NAME
 
-Jenkins::i18n::Warnings - class to handle translation warnings
+Jenkins::i18n::Warnings - stores and handles translation warnings
 
 =head1 SYNOPSIS
 
-  use Jenkins::i18n::Warnings;
+    use Jenkins::i18n::Warnings;
 
 =head1 DESCRIPTION
 
@@ -37,7 +37,10 @@ All attributes are "private".
 
 Creates a new instance.
 
-Expects no parameters, returns a new instance.
+Expects as single parameter a boolean (0 or 1) to mark the instance as
+"silent". That means that the return values of some methods will be affected by
+this option, please check the documentation of the methods available in this
+class for more details.
 
 =cut
 
@@ -157,10 +160,16 @@ sub reset {
 
 =head2 summary
 
-Prints to C<STDERR> all collected warnings so far, one per line.
+Returns "true" (1) or "false" (0) if there are any warnings registered for a
+single file.
 
 Expects as parameter the translation file being processed.
 
+If the class instance wasn't created as "silent" prints to C<STDERR> all
+collected warnings so far, one per line.
+
+Otherwise, nothing will be printed.
+
 =cut
 
 sub summary {
@@ -178,10 +187,11 @@ sub summary {
         }
     }
 
-    # required for predicable warnings order
-    my @sorted_types = sort( keys( %{ $self->{types} } ) );
-
     if ( ($has_any) and ( not $self->{silent} ) ) {
+
+        # required for predicable warnings order
+        my @sorted_types = sort( keys( %{ $self->{types} } ) );
+
         my $rel = $self->_relative_path($file);
         warn "Got warnings for $rel:\n";
 
@@ -191,10 +201,9 @@ sub summary {
             }
         }
 
-        return 1;
     }
 
-    return 0;
+    return ( ( $has_any > 0 ) ? 1 : 0 );
 }
 
 sub _relative_path {
@@ -280,9 +289,9 @@ details.
 You should have received a copy of the GNU General Public License along with
 Jenkins Translation Tool. If not, see (http://www.gnu.org/licenses/).
 
-The original `translation-tool.pl` script was licensed through the MIT License,
-copyright (c) 2004-, Kohsuke Kawaguchi, Sun Microsystems, Inc., and a number of
-other of contributors. Translations files generated by the Jenkins Translation
-Tool CLI are distributed with the same MIT License.
+The original C<translation-tool.pl> script was licensed through the MIT
+License, copyright (c) 2004-, Kohsuke Kawaguchi, Sun Microsystems, Inc., and a
+number of other of contributors. Translations files generated by the Jenkins
+Translation Tool CLI are distributed with the same MIT License.
 
 =cut
